@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -
-# Copyright (c) 2008, Benoît Chesneau <benoitc@e-engura.com>
+# Copyright (c) 2008, 2009 Benoît Chesneau <benoitc@e-engura.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,7 +13,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-""" simple couchdb client 
+#
+""" 
+simple couchdb client 
+~~~~~~~~~~~~~~~~~~~~~
+
 """
 
 from simplecouchdb.client.view import *
