@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -
-# Copyright (c) 2008, Benoît Chesneau <benoitc@e-engura.com>
+# Copyright (c) 2008, 2009 Benoît Chesneau <benoitc@e-engura.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,7 +19,7 @@
 from mimetypes import guess_type
 
 from simplecouchdb.client.utils import validate_dbname
-from simplecouchdb.client.view import View, TemporaryView, AllDocumentsView, view_cache, register_view, ViewDefinition
+from simplecouchdb.client.view import View, SlowView, AllDocumentsView, view_cache, register_view, ViewDefinition
 from simplecouchdb.resource import ResourceNotFound
 
 class InvalidAttachment(Exception):
@@ -46,7 +46,7 @@ class Database(object):
         self.res = server.res.clone()
         self.res.update_uri('/%s' % dbname)
         self._view = View(self)
-        self._temp_view = TemporaryView(self)
+        self._slow_view = SlowView(self)
         self._all_documents_view = AllDocumentsView(self)
 
     def info(self):
@@ -216,12 +216,12 @@ class Database(object):
         return self._view
 
     @property
-    def temp_view(self):
+    def slow_view(self):
         """ 
         See :ref:`view-ref` documentation
 
         :return: TemporaryView instance """
-        return self._temp_view
+        return self._slow_view
 
     def add_attachment(self, doc, content, name=None, content_type=None):
         """ Add attachement to a document.
@@ -355,3 +355,4 @@ class Database(object):
         
     def __nonzero__(self):
         return (len(self) > 0)
+
