@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -
-# Copyright (c) 2008, Benoît Chesneau <benoitc@e-engura.com>
+# Copyright (c) 2008, 2009, Benoît Chesneau <benoitc@e-engura.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -175,15 +175,15 @@ class View(object):
         Return:
             int
         """
-        results = self.get(view_name, count=0)
+        results = self.get(view_name, limit=0)
         return len(results)
 
     def _make_request(self): 
         results, resp =  self.res.get(**self.params)
         return results
 
-class TemporaryView(View):
-    """ Temporary view representation
+class SlowView(View):
+    """ Slow view representation
 
     """
 
@@ -192,7 +192,7 @@ class TemporaryView(View):
         """ get results 
 
         Args:
-        design: dict or string of a temporary view:
+        design: dict or string of a slow view:
             design_doc = {
                 "map": \"\"\"function(doc) { 
                     if (doc.docType == "test") { 
@@ -214,7 +214,7 @@ class TemporaryView(View):
         return ViewResults(self, wrapper=wrapper, **params)
 
     def _make_request(self):
-        results, resp = self.res.post('_temp_view', data=self.design,
+        results, resp = self.res.post('_slow_view', data=self.design,
                 **self.params)
         return results
 
